# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/20_plot.ipynb.

# %% auto 0
__all__ = ['PROJ', 'PLOT', 'PROJECTION', 'CMAP', 'COLOR_MAP', 'COLOR', 'LABEL', 'TITLE', 'SUPTITLE', 'EDGECOLOR', 'FACECOLOR']

# %% ../nbs/20_plot.ipynb 5
PROJ = 'proj'
PLOT = 'plot'
PROJECTION = f'{PROJ}ection'
CMAP = 'cmap'
COLOR_MAP = 'color_map'
COLOR = 'color'
LABEL = 'label'
TITLE = 'title'
SUPTITLE = f'sup{TITLE}'
EDGECOLOR = f'edge{COLOR}'
FACECOLOR = f'face{COLOR}'




# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/31_mthd.ipynb.

# %% auto 0
__all__ = ['DPT', 'PCA', 'UMAP', 'TSNE', 'PHATE', 'MAGIC', 'SCORE', 'ZSCORE', 'GZSCORE', 'LOG', 'LOG1P', 'OT', 'MMD', 'PSEUDO',
           'PSEUDOTIME', 'DPT_PSEUDOTIME']

# %% ../nbs/31_mthd.ipynb 4
from nchr import S_
from .exps import TIME

# %% ../nbs/31_mthd.ipynb 6
DPT   = 'dpt'
PCA   = 'pca'
UMAP  = 'umap'
TSNE  = 'tsne'
PHATE = 'phate'
MAGIC = 'magic'

SCORE = 'score'
ZSCORE = f'z{SCORE}'
GZSCORE = f'g{ZSCORE}'


LOG = 'log'
LOG1P = f'{LOG}1p'

OT = 'ot'
MMD = 'mmd'

# %% ../nbs/31_mthd.ipynb 7
PSEUDO = 'pseudo'
PSEUDOTIME = f'{PSEUDO}{TIME}'
DPT_PSEUDOTIME = f'{DPT}{S_}{PSEUDOTIME}'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/04_dund.ipynb.

# %% auto 0
__all__ = ['MRO', 'NEW', 'CALL', 'INIT', 'NAME', 'ANNOTATIONS']

# %% ../nbs/04_dund.ipynb 5
MRO = 'mro'
NEW = 'new'
CALL = 'call'
INIT = 'init'
NAME = 'name'
ANNOTATIONS = 'annotations'

# %% ../nbs/04_dund.ipynb 6
__EQ__ = '__eq__'
__NE__ = '__ne__'
__LT__ = '__lt__'
__LE__ = '__le__'
__GT__ = '__gt__'
__GE__ = '__ge__'

__STR__ = '__str__'
__NEW__ = '__new__'
__DIR__ = '__dir__'
__LEN__ = '__len__'
__GET__ = '__get__'
__SET__ = '__set__'
__MRO__ = '__mro__'
__DOC__ = '__doc__'

__INIT__ = '__init__'
__REPR__ = '__repr__'
__CALL__ = '__call__'
__ITER__ = '__iter__'
__NEXT__ = '__next__'
__NAME__ = '__name__'


__HASH__ = '__hash__'
__BOOL__ = '__bool__'
__EXIT__ = '__exit__'
__DICT__ = '__dict__'

__ENTER__ = '__enter__'
__CLASS__ = '__class__'

__FORMAT__ = '__format__'

__GETATTR__ = '__getattr__'
__SETATTR__ = '__setattr__'
__DELATTR__ = '__delattr__'

__GETITEM__ = '__getitem__'
__SETITEM__ = '__setitem__'
__DELITEM__ = '__delitem__'

__PREPARE__ = '__prepare__'

__CONTAINS__ = '__contains__'
__REVERSED__ = '__reversed__'

__MOD__ = '__mod__'
__MUL__ = '__mul__'
__TRUEDIV__ = '__truediv__'
__FLOORDIV__ = '__floordiv__'
__ADD__ = '__add__'
__SUB__ = '__sub__'
__POW__ = '__pow__'

__RADD__ = '__radd__'
__RSUB__ = '__rsub__'
__RMUL__ = '__rmul__'
__RDIV__ = '__rdiv__'

__IADD__ = '__iadd__'
__ISUB__ = '__isub__'
__IMUL__ = '__imul__'
__IDIV__ = '__idiv__'

__BYTES__ = '__bytes__'
__INDEX__ = '__index__'
__SLICE__ = '__slice__'

__INIT_SUBCLASS__ = '__init_subclass__'
__INSTANCECHECK__ = '__instancecheck__'
__SUBCLASSCHECK__ = '__subclasscheck__'


# %% ../nbs/04_dund.ipynb 7
__SLOTS__ = '__slots__'

# %% ../nbs/04_dund.ipynb 9
__ALL__ = '__all__'
__FILE__ = '__file__'
__NAME__ = '__name__'
__SPEC__ = '__spec__'
__CACHED__ = '__cached__'
__LOADER__ = '__loader__'
__MODULE__ = '__module__'
__PACKAGE__ = '__package__'
__BUILTINS__ = '__builtins__'

# %% ../nbs/04_dund.ipynb 11
__AWAIT__ = '__await__'
__AENTER__ = '__aenter__'
__AEXIT__ = '__aexit__'
__ANEXT__ = '__anext__'
__AITER__ = '__aiter__'

__ABS__ = '__abs__'
__CMPLX__ = '__complex__'
__FLOAT__ = '__float__'
__INT__ = '__int__'
__ROUND__ = '__round__'

__DIVMOD__ = '__divmod__'
__RDIVMOD__ = '__rdivmod__'
__IPOW__ = '__ipow__'
__IMOD__ = '__imod__'
__IMATMUL__ = '__imatmul__'

__IFLOORDIV__ = '__ifloordiv__'
__ITRUEDIV__ = '__itruediv__'
__INVERT__ = '__invert__'
__LSHIFT__ = '__lshift__'
__RSHIFT__ = '__rshift__'

__ILSHIFT__ = '__ilshift__'
__IRSHIFT__ = '__irshift__'
__IOR__ = '__ior__'
__IXOR__ = '__ixor__'
__IAND__ = '__iand__'


# %% ../nbs/04_dund.ipynb 13
__FSPATH__ = '__fspath__'

# %% ../nbs/04_dund.ipynb 15
__MEMBERS__ = '__members__'
__RESTORE__ = '__restore__'
__METACLASS__ = '__metaclass__'

# %% ../nbs/04_dund.ipynb 17
__COPYING__   = '__copying__'
__DEFAULT__   = '__default__'
__PASSCLS__   = '__passcls__'
__PASSINS__   = '__passins__'

__PASSSELF__  = '__passself__'
__READONLY__  = '__readonly__'

__PAIRWISE__  = '__pairwise__'
__INNER_OP__  = '__inner_op__'

__ATTRSPECS__ = '__attrspecs__'
__SINGLETON__ = '__singleton__'
__INHERITING__ = '__inheriting__'

__INHERITABLE_MEMBERS__ = '__inheritable_members__'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/62_pddf.ipynb.

# %% auto 0
__all__ = ['CAT', 'CATEGORY', 'CATEGORIES', 'COL', 'COLS', 'COLUMNS', 'GET', 'SHAPE']

# %% ../nbs/62_pddf.ipynb 5
CAT = 'cat'
CATEGORY = f'{CAT}egory'
CATEGORIES = f'{CAT}egories'

# %% ../nbs/62_pddf.ipynb 6
COL = 'col'
COLS = f'{COL}s'
COLUMNS = f'{COL}umns'

# %% ../nbs/62_pddf.ipynb 7
GET = 'get'
SHAPE = f'shape'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/30_exps.ipynb.

# %% auto 0
__all__ = ['ID', 'IDX', 'CAT', 'ITEM', 'NAME', 'SEED', 'BATCH', 'TOTAL', 'METHOD', 'PCT', 'PERCENT', 'DAY', 'TIME', 'TIMEPOINT',
           'TIMEPOINTS', 'COUNT', 'NORM', 'NORMALIZED', 'CON', 'CONDITION', 'CONDITIONS', 'SAMPLE', 'SAMPLES',
           'TREATMENT', 'TREATMENTS', 'SENS', 'SENSITIVITY', 'SENSITIVITIES', 'CATEGORY', 'CATEGORIES', 'CLST',
           'LEIDEN', 'CLUSTER', 'LOUVAIN', 'CLIP', 'SUBSET', 'REPLACE', 'SD', 'SD1', 'SD2', 'SD3']

# %% ../nbs/30_exps.ipynb 4
from nchr import S_

# %% ../nbs/30_exps.ipynb 6
ID = 'id'
IDX = 'idx'
CAT = 'cat'

# %% ../nbs/30_exps.ipynb 7
ITEM = 'item'
NAME = 'name'
SEED = 'seed'

# %% ../nbs/30_exps.ipynb 8
BATCH = 'batch'
TOTAL = 'total'

# %% ../nbs/30_exps.ipynb 9
METHOD = 'method'

# %% ../nbs/30_exps.ipynb 10
PCT = 'pct'
PERCENT = 'percent'

# %% ../nbs/30_exps.ipynb 11
DAY = 'day'
TIME = 'time'
TIMEPOINT = f'{TIME}point'
TIMEPOINTS = f'{TIMEPOINT}s'

# %% ../nbs/30_exps.ipynb 12
COUNT = 'count'

# %% ../nbs/30_exps.ipynb 13
NORM = 'norm'
NORMALIZED = f'{NORM}alized'

# %% ../nbs/30_exps.ipynb 14
CON = 'con'
CONDITION = f'{CON}dition'
CONDITIONS = f'{CONDITION}s'

# %% ../nbs/30_exps.ipynb 15
SAMPLE = 'sample'
SAMPLES = f'{SAMPLE}s'

# %% ../nbs/30_exps.ipynb 16
TREATMENT = f'treatment'
TREATMENTS = f'{TREATMENT}s'

# %% ../nbs/30_exps.ipynb 17
SENS = 'sens'
SENSITIVITY = f'{SENS}itivity'
SENSITIVITIES = f'{SENS}itivities'

# %% ../nbs/30_exps.ipynb 18
CATEGORY = 'category'
CATEGORIES = 'categories'

# %% ../nbs/30_exps.ipynb 19
CLST = 'clst'
LEIDEN = 'leiden'
CLUSTER = 'cluster'
LOUVAIN = 'louvain'

# %% ../nbs/30_exps.ipynb 20
CLIP = 'clip'
SUBSET = 'subset'
REPLACE = 'replace'

# %% ../nbs/30_exps.ipynb 21
SD = 'sd'
SD1 = f'{SD}1'
SD2 = f'{SD}2'
SD3 = f'{SD}3'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_args.ipynb.

# %% auto 0
__all__ = ['N', 'IDX', 'SEP', 'FMT', 'KEY', 'POS', 'CAT', 'ATTR', 'DESC', 'FUNC', 'KIND', 'TYPE', 'REPR', 'OPTS', 'SHOW', 'PREF',
           'KEYS', 'PREP', 'LINK', 'PATH', 'HUSH', 'QUIET', 'RAISE', 'FAILQ', 'SPEC', 'SPECS', 'ANTI', 'PTTN',
           'PATTERN', 'ANTI_PTTN', 'DEBUG', 'PRINT', 'VALUE', 'COLOR', 'LABEL', 'TITLE', 'NBINS', 'CUTOFF', 'MIXINS',
           'UNIQUE', 'HIDDEN', 'IGNORE', 'DEFAULT', 'INPLACE', 'VERBOSE', 'REVERSE', 'EXCLUDE', 'OPTIONAL', 'REQUIRED',
           'ASMEMBER', 'ABRV', 'SYMB', 'CONS', 'FMTFUNC', 'MOD', 'PKG', 'ARG', 'KWS', 'KWDS', 'ARGS', 'KWARGS', 'VARG',
           'VKWS', 'VARGS', 'VKWDS', 'VKWARGS', 'SELF', 'BEG', 'END', 'NEG', 'LEN', 'DIG', 'BRV', 'FIX', 'OVERWRITE',
           'OVERWRITABLE']

# %% ../nbs/02_args.ipynb 5
N = 'n'

# %% ../nbs/02_args.ipynb 6
IDX = 'idx'
SEP = 'sep'
FMT = 'fmt'
KEY = 'key'
POS = 'pos'
CAT = 'cat'

# %% ../nbs/02_args.ipynb 7
ATTR = 'attr'
DESC = 'desc'
FUNC = 'func'
KIND = 'kind'
TYPE = 'type'
REPR = 'repr'
OPTS = 'opts'
SHOW = 'show'
PREF = 'pref'
KEYS = 'keys'
PREP = 'prep'

# %% ../nbs/02_args.ipynb 8
LINK = 'link'
PATH = 'path'

# %% ../nbs/02_args.ipynb 9
HUSH = 'hush'
QUIET = 'quiet'
RAISE = 'raise'
FAILQ = 'failq'

# %% ../nbs/02_args.ipynb 10
SPEC = 'spec'
SPECS = f'{SPEC}s'

# %% ../nbs/02_args.ipynb 11
ANTI = 'anti'
PTTN = 'pttn'
PATTERN = 'pattern'

ANTI_PTTN = f'{ANTI}_{PTTN}'

# %% ../nbs/02_args.ipynb 12
DEBUG = 'debug'
PRINT = 'print'
VALUE = 'value'

COLOR = 'color'
LABEL = 'label'
TITLE = 'title'

NBINS = 'nbins'

# %% ../nbs/02_args.ipynb 13
CUTOFF = 'cutoff'
MIXINS = 'mixins'
UNIQUE = 'unique'

# %% ../nbs/02_args.ipynb 14
HIDDEN = 'hidden'
IGNORE = 'ignore'


# %% ../nbs/02_args.ipynb 15
DEFAULT = 'default'
INPLACE = 'inplace'
VERBOSE = 'verbose'
REVERSE = 'reverse'
EXCLUDE = 'exclude'


# %% ../nbs/02_args.ipynb 16
OPTIONAL = 'optional'
REQUIRED = 'required'

# %% ../nbs/02_args.ipynb 18
ASMEMBER = 'asmember'

# %% ../nbs/02_args.ipynb 20
ABRV = 'abrv'
SYMB = 'symb'

CONS = 'cons'

# %% ../nbs/02_args.ipynb 21
FMTFUNC = f'{FMT}{FUNC}'

# %% ../nbs/02_args.ipynb 24
MOD = 'mod'
PKG = 'pkg'

# %% ../nbs/02_args.ipynb 26
ARG = 'arg'
KWS = 'kws'
KWDS = 'kwds'
ARGS = f'{ARG}s'
KWARGS = f'kw{ARGS}'
VARG = f'v{ARG}'
VKWS = f'v{KWS}'
VARGS = f'v{ARGS}'
VKWDS = f'v{KWDS}'
VKWARGS = f'v{KWARGS}'
SELF = 'self'

# %% ../nbs/02_args.ipynb 28
BEG = 'beg' # beginning
END = 'end' # end / ending

POS = 'pos' # positive
NEG = 'neg' # nevative

LEN = 'len' # length
DIG = 'dig' # digits

BRV = 'brv' # brv / abbreviation
FIX = 'fix' # prefix / suffix

# %% ../nbs/02_args.ipynb 30
OVERWRITE = 'overwrite'
OVERWRITABLE = 'overwritable'



__version__ = "0.0.26"
# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00__init__.ipynb.

# %% auto 0
__all__ = []

# %% ../nbs/00__init__.ipynb 3
from itertools import chain

from nlit import (
    args, sund, dund, vals, errs, math as mmod, attr, dict as dmod, plot, clrs, exps, mthd, embs, biol, 
    cell, fmtx, path, exts, tree, mods, docs, nbks, vers, narr, tens, pddf,
    unit, expo, byte, bkts, hrdw
)
from .args import *
from .sund import *
from .dund import *
from .vals import *
from .errs import *
from .math import *
from .attr import *
from .dict import *
from .plot import *
from .clrs import *
from .exps import *
from .mthd import *
from .embs import *
from .biol import *
from .cell import *
from .fmtx import *
from .path import *
from .exts import *
from .tree import *
from .mods import *
from .docs import *
from .nbks import *
from .vers import *
from .narr import *
from .tens import *
from .pddf import *
from .unit import *
from .expo import *
from .byte import *
from .bkts import *
from .hrdw import *

# %% ../nbs/00__init__.ipynb 4
for mod in (sund, dund):
    for k in filter(str.isupper, dir(dund)):
        globals()[k] = getattr(dund, k)
        dund.__all__.append(k)

# %% ../nbs/00__init__.ipynb 5
__all__ = sorted(set(chain(*[
    mod.__all__ for mod in (
        args, sund, dund, vals, errs, mmod, attr, dmod, plot, clrs, exps, mthd, embs, biol, cell, fmtx, path, exts, tree, mods, 
        docs, nbks, vers, narr, tens, pddf, unit, expo, byte, bkts, hrdw, 
    )
])))



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/91_expo.ipynb.

# %% auto 0
__all__ = ['EXPO_ONE', 'EXPO_DECA', 'EXPO_HECTO', 'EXPO_KILO', 'EXPO_MEGA', 'EXPO_GIGA', 'EXPO_TERA', 'EXPO_PETA', 'EXPO_EXA',
           'EXPO_ZETTA', 'EXPO_YOTTA', 'EXPO_RONNA', 'EXPO_QUETTA', 'EXPO_DECI', 'EXPO_CENTI', 'EXPO_MILLI',
           'EXPO_MICRO', 'EXPO_NANO', 'EXPO_PICO', 'EXPO_FEMTO', 'EXPO_ATTO', 'EXPO_ZEPTO', 'EXPO_YOCTO', 'EXPO_RONTO',
           'EXPO_QUECTO', 'ExpoInfo', 'Expo']

# %% ../nbs/91_expo.ipynb 4
from enum import Enum
from typing import NamedTuple

# %% ../nbs/91_expo.ipynb 5
from .unit import UNIT_NAMES, UNIT_ABRVS, UNIT_SYMBS

# %% ../nbs/91_expo.ipynb 7
class ExpoInfo(NamedTuple):
    name: str; abrv: str; symb: str; expo: float;

# %% ../nbs/91_expo.ipynb 8
EXPO_ONE    = ExpoInfo(UNIT_NAMES[0], UNIT_ABRVS[0], UNIT_SYMBS[0], 1e0)
EXPO_DECA   = ExpoInfo(UNIT_NAMES[1],  UNIT_ABRVS[1],  UNIT_SYMBS[1],  1e+1)
EXPO_HECTO  = ExpoInfo(UNIT_NAMES[2],  UNIT_ABRVS[2],  UNIT_SYMBS[2],  1e+2)
EXPO_KILO   = ExpoInfo(UNIT_NAMES[3],  UNIT_ABRVS[3],  UNIT_SYMBS[3],  1e+3)
EXPO_MEGA   = ExpoInfo(UNIT_NAMES[4],  UNIT_ABRVS[4],  UNIT_SYMBS[4],  1e+6)
EXPO_GIGA   = ExpoInfo(UNIT_NAMES[5],  UNIT_ABRVS[5],  UNIT_SYMBS[5],  1e+9)
EXPO_TERA   = ExpoInfo(UNIT_NAMES[6],  UNIT_ABRVS[6],  UNIT_SYMBS[6],  1e+12)
EXPO_PETA   = ExpoInfo(UNIT_NAMES[7],  UNIT_ABRVS[7],  UNIT_SYMBS[7],  1e+15)
EXPO_EXA    = ExpoInfo(UNIT_NAMES[8],  UNIT_ABRVS[8],  UNIT_SYMBS[8],  1e+18)
EXPO_ZETTA  = ExpoInfo(UNIT_NAMES[9],  UNIT_ABRVS[9],  UNIT_SYMBS[9],  1e+21)
EXPO_YOTTA  = ExpoInfo(UNIT_NAMES[10], UNIT_ABRVS[10], UNIT_SYMBS[10], 1e+24)
EXPO_RONNA  = ExpoInfo(UNIT_NAMES[11], UNIT_ABRVS[11], UNIT_SYMBS[11], 1e+27)
EXPO_QUETTA = ExpoInfo(UNIT_NAMES[12], UNIT_ABRVS[12], UNIT_SYMBS[12], 1e+30)

EXPO_DECI   = ExpoInfo(UNIT_NAMES[13], UNIT_ABRVS[13], UNIT_SYMBS[13], 1e-1)
EXPO_CENTI  = ExpoInfo(UNIT_NAMES[14], UNIT_ABRVS[14], UNIT_SYMBS[14], 1e-2)
EXPO_MILLI  = ExpoInfo(UNIT_NAMES[15], UNIT_ABRVS[15], UNIT_SYMBS[15], 1e-3)
EXPO_MICRO  = ExpoInfo(UNIT_NAMES[16], UNIT_ABRVS[16], UNIT_SYMBS[16], 1e-6)
EXPO_NANO   = ExpoInfo(UNIT_NAMES[17], UNIT_ABRVS[17], UNIT_SYMBS[17], 1e-9)
EXPO_PICO   = ExpoInfo(UNIT_NAMES[18], UNIT_ABRVS[18], UNIT_SYMBS[18], 1e-12)
EXPO_FEMTO  = ExpoInfo(UNIT_NAMES[19], UNIT_ABRVS[19], UNIT_SYMBS[19], 1e-15)
EXPO_ATTO   = ExpoInfo(UNIT_NAMES[20], UNIT_ABRVS[20], UNIT_SYMBS[20], 1e-18)
EXPO_ZEPTO  = ExpoInfo(UNIT_NAMES[21], UNIT_ABRVS[21], UNIT_SYMBS[21], 1e-21)
EXPO_YOCTO  = ExpoInfo(UNIT_NAMES[22], UNIT_ABRVS[22], UNIT_SYMBS[22], 1e-24)
EXPO_RONTO  = ExpoInfo(UNIT_NAMES[23], UNIT_ABRVS[23], UNIT_SYMBS[23], 1e-27)
EXPO_QUECTO = ExpoInfo(UNIT_NAMES[24], UNIT_ABRVS[24], UNIT_SYMBS[24], 1e-30)

# %% ../nbs/91_expo.ipynb 10
class Expo(Enum):
    ONE    = EXPO_ONE
    DECA   = EXPO_DECA
    HECTO  = EXPO_HECTO
    KILO   = EXPO_KILO
    MEGA   = EXPO_MEGA
    GIGA   = EXPO_GIGA
    TERA   = EXPO_TERA
    PETA   = EXPO_PETA
    EXA    = EXPO_EXA
    ZETTA  = EXPO_ZETTA
    YOTTA  = EXPO_YOTTA
    RONNA  = EXPO_RONNA
    QUETTA = EXPO_QUETTA
    DECI   = EXPO_DECI
    CENTI  = EXPO_CENTI
    MILLI  = EXPO_MILLI
    MICRO  = EXPO_MICRO
    NANO   = EXPO_NANO
    PICO   = EXPO_PICO
    FEMTO  = EXPO_FEMTO
    ATTO   = EXPO_ATTO
    ZEPTO  = EXPO_ZEPTO
    YOCTO  = EXPO_YOCTO
    RONTO  = EXPO_RONTO
    QUECTO = EXPO_QUECTO
